ResponsiveScreen class
当前屏幕
- Available extensions
Constructors
- ResponsiveScreen({required Size screenSize, required ResponsiveScreenType screenType})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDesktop → bool
-
Available on ResponsiveScreen, provided by the ResponsiveScreenExt extension
no setter - isLandscape → bool
-
Available on ResponsiveScreen, provided by the ResponsiveScreenExt extension
no setter - isPhone → bool
-
Available on ResponsiveScreen, provided by the ResponsiveScreenExt extension
no setter - isTablet → bool
-
Available on ResponsiveScreen, provided by the ResponsiveScreenExt extension
no setter - isTabletOrDesktop → bool
-
Available on ResponsiveScreen, provided by the ResponsiveScreenExt extension
no setter - isWatch → bool
-
Available on ResponsiveScreen, provided by the ResponsiveScreenExt extension
no setter - orientation → Orientation
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenSize → Size
-
final
- screenType → ResponsiveScreenType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveValue<
T> ({required T defValue, T? defLandscape, T? phone, T? phoneLandscape, T? tablet, T? tabletLandscape, T? desktop, T? largeDesktop, T? watch}) → T -
Available on ResponsiveScreen, provided by the ResponsiveScreenExt extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited