ResponsiveScreenDpiSettings class

响应式屏幕 dpi 配置

Constructors

ResponsiveScreenDpiSettings({required ScreenDpiRange desktopDpi, required ScreenDpiRange tabletDpi, required ScreenDpiRange phoneDpi, required ScreenDpiRange watchDpi})
const

Properties

desktopDpi ScreenDpiRange
final
hashCode int
The hash code for this object.
no setterinherited
phoneDpi ScreenDpiRange
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabletDpi ScreenDpiRange
final
watchDpi ScreenDpiRange
final

Methods

getScreenType(double dpi) ResponsiveScreenType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited