ScreenDpiRange class

屏幕 dpi 范围 可设置 范围值 不可都为空

Constructors

ScreenDpiRange({double? minDpi, double? maxDpi})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxDpi double?
最大 dpi
final
minDpi double?
最小 dpi
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isInRange(double dpi) bool
判断 dpi 是否在范围中 dpi >= minDpi && dpi < maxDpi
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited